1.0.0 API documentation: vector_uint4_sized.hpp File Reference

| 1.0.0 API documentation

Typedefs
vector_uint4_sized.hpp File Reference

GLM_EXT_vector_uint4_sized More...

Go to the source code of this file.

## Typedefs
typedef vec< 4, uint16, defaultp > | u16vec4
| 16 bit unsigned integer vector of 4 components type. More...
typedef vec< 4, uint32, defaultp > | u32vec4
| 32 bit unsigned integer vector of 4 components type. More...
typedef vec< 4, uint64, defaultp > | u64vec4
| 64 bit unsigned integer vector of 4 components type. More...
typedef vec< 4, uint8, defaultp > | u8vec4
| 8 bit unsigned integer vector of 4 components type. More...

## Detailed Description

GLM_EXT_vector_uint4_sized

Definition in file vector_uint4_sized.hpp.